.. toctree::
    :hidden:
    :maxdepth: 2
    :caption: Contents:

    Home <self>
    User Guide <user/index>
    Development Guide <devel/index>
    Plugin Catalogue <plugins_cata>
    Full API <api/modules>
    Citation <citation>
    Project Page <https://github.com/ucl-exoplanets/TauREx3_public/>


TauREx |version| - A true exoplanet retrieval framework
=======================================================

    |image1|

TauREx 3 (Tau Retrieval for Exoplanets) is an open-source
fully bayesian inverse atmospheric retrieval framework licensed
under BSDv3.
It aims to make exoplanetary atmosphere modelling and retrievals
fast, easy and flexible!

TauREx 3 offers a fully customizable framework that allows you
to mix and match atmospheric parameters and add in your own to
perform modelling and retrievals.

For scientists, the standalone taurex program provides a wealth
of parameters to build forward models, simulate instruments and
perform retrievals.

For developers, TauREx3 provides a rich library of classes to
build your own programs and any new atmospheric parameters you
create can be used in the standalone program like it was always there!

TauREx3 can be expanded


If you use TauREx 3 in you work, please see the guide to :ref:`Citations`.


-----------------------------------

Want to install it? Head here: :ref:`installation`

Want to jump into the ``taurex`` program? Head here: :ref:`quickstart`

Want to try out the library? Try here: :ref:`library`

----------------------------------

:Release: |release|

.. |image1| image::  _static/taurex_logo.png
    :align: middle
    :height: 180
